package cn.com.infosec.jce;

import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.SubjectPublicKeyInfo;
import cn.com.infosec.asn1.x509.TBSCertificateStructure;
import cn.com.infosec.asn1.x509.Time;
import cn.com.infosec.asn1.x509.V3TBSCertificateGenerator;
import cn.com.infosec.asn1.x509.X509CertificateStructure;
import cn.com.infosec.asn1.x509.X509Extension;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.asn1.x509.X509Name;
import cn.com.infosec.jce.provider.X509CertificateObject;
import cn.com.infosec.util.Strings;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.SecureRandom;
import java.security.Signature;
import java.security.cert.X509Certificate;
import java.util.Date;
import java.util.Hashtable;
import java.util.Vector;

/** @deprecated */
public class X509V3CertificateGenerator {
   private static Hashtable algorithms;
   private V3TBSCertificateGenerator tbsGen;
   private DERObjectIdentifier sigOID;
   private AlgorithmIdentifier sigAlgId;
   private String signatureAlgorithm;
   private Hashtable extensions;
   private Vector extOrdering;

   static {
      Hashtable var10000 = algorithms = new Hashtable();
      DERObjectIdentifier var0;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.2");
      var10000.put("MD2WITHRSAENCRYPTION", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.2");
      var10000.put("MD2WITHRSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.4");
      var10000.put("MD5WITHRSAENCRYPTION", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.4");
      var10000.put("MD5WITHRSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.5");
      var10000.put("SHA1WITHRSAENCRYPTION", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.113549.1.1.5");
      var10000.put("SHA1WITHRSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.3.36.3.3.1.2");
      var10000.put("RIPEMD160WITHRSAENCRYPTION", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.3.36.3.3.1.2");
      var10000.put("RIPEMD160WITHRSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.10040.4.3");
      var10000.put("SHA1WITHDSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.10040.4.3");
      var10000.put("DSAWITHSHA1", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.10045.4.1");
      var10000.put("SHA1WITHECDSA", var0);
      var10000 = algorithms;
      var0 = new DERObjectIdentifier.<init>("1.2.840.10045.4.1");
      var10000.put("ECDSAWITHSHA1", var0);
   }

   public X509V3CertificateGenerator() {
      X509V3CertificateGenerator var10000 = this;
      super();
      this.extensions = null;
      this.extOrdering = null;
      V3TBSCertificateGenerator var1;
      var1 = new V3TBSCertificateGenerator.<init>();
      var10000.tbsGen = var1;
   }

   public void reset() {
      X509V3CertificateGenerator var10000 = this;
      X509V3CertificateGenerator var10001 = this;
      X509V3CertificateGenerator var10002 = this;
      V3TBSCertificateGenerator var1;
      var1 = new V3TBSCertificateGenerator.<init>();
      var10002.tbsGen = var1;
      var10001.extensions = null;
      var10000.extOrdering = null;
   }

   public void setSerialNumber(BigInteger serialNumber) {
      this.tbsGen.setSerialNumber(new DERInteger(serialNumber));
   }

   public void setIssuerDN(X509Name issuer) {
      this.tbsGen.setIssuer(issuer);
   }

   public void setNotBefore(Date date) {
      this.tbsGen.setStartDate(new Time(date));
   }

   public void setNotAfter(Date date) {
      this.tbsGen.setEndDate(new Time(date));
   }

   public void setSubjectDN(X509Name subject) {
      this.tbsGen.setSubject(subject);
   }

   public void setPublicKey(PublicKey key) {
      try {
         this.tbsGen.setSubjectPublicKeyInfo(new SubjectPublicKeyInfo((ASN1Sequence)(new ASN1InputStream(new ByteArrayInputStream(key.getEncoded()))).readObject()));
      } catch (Exception var2) {
         throw new IllegalArgumentException("unable to process key - " + var2.toString());
      }
   }

   public void setSignatureAlgorithm(String signatureAlgorithm) {
      this.signatureAlgorithm = signatureAlgorithm;
      DERObjectIdentifier signatureAlgorithm1;
      DERObjectIdentifier var10000 = signatureAlgorithm1 = (DERObjectIdentifier)algorithms.get(Strings.toUpperCase(signatureAlgorithm));
      this.sigOID = signatureAlgorithm1;
      if (var10000 != null) {
         X509V3CertificateGenerator var2 = this;
         X509V3CertificateGenerator var10001 = this;
         AlgorithmIdentifier var3;
         AlgorithmIdentifier var10002 = var3 = new AlgorithmIdentifier;
         DERObjectIdentifier var10004 = signatureAlgorithm1;
         DERNull signatureAlgorithm2;
         signatureAlgorithm2 = new DERNull.<init>();
         var10002.<init>(var10004, signatureAlgorithm2);
         var10001.sigAlgId = var10002;
         var2.tbsGen.setSignature(var3);
      } else {
         throw new IllegalArgumentException("Unknown signature type requested");
      }
   }

   public void addExtension(String OID, boolean critical, DEREncodable value) {
      X509V3CertificateGenerator var10000 = this;
      DERObjectIdentifier var4;
      var4 = new DERObjectIdentifier.<init>(OID);
      var10000.addExtension(var4, critical, value);
   }

   public void addExtension(DERObjectIdentifier OID, boolean critical, DEREncodable value) {
      if (this.extensions == null) {
         Hashtable var4;
         var4 = new Hashtable.<init>();
         this.extensions = var4;
         Vector var8;
         var8 = new Vector.<init>();
         this.extOrdering = var8;
      }

      X509V3CertificateGenerator var10000 = this;
      ByteArrayOutputStream var6;
      ByteArrayOutputStream var10001 = var6 = new ByteArrayOutputStream;
      var10001.<init>();
      DEREncodable var10003 = value;
      DEROutputStream var10002 = new DEROutputStream(var6);

      try {
         var10002.writeObject(var10003);
      } catch (IOException var5) {
         throw new IllegalArgumentException("error encoding value: " + var5);
      }

      byte[] var7 = var10001.toByteArray();
      var10000.addExtension(OID, critical, var7);
   }

   public void addExtension(String OID, boolean critical, byte[] value) {
      X509V3CertificateGenerator var10000 = this;
      DERObjectIdentifier var4;
      var4 = new DERObjectIdentifier.<init>(OID);
      var10000.addExtension(var4, critical, value);
   }

   public void addExtension(DERObjectIdentifier OID, boolean critical, byte[] value) {
      if (this.extensions == null) {
         Hashtable var4;
         var4 = new Hashtable.<init>();
         this.extensions = var4;
         Vector var7;
         var7 = new Vector.<init>();
         this.extOrdering = var7;
      }

      X509V3CertificateGenerator var10000 = this;
      Hashtable var10001 = this.extensions;
      X509Extension var5;
      X509Extension var10003 = var5 = new X509Extension;
      boolean var10004 = critical;
      DEROctetString critical1;
      critical1 = new DEROctetString.<init>(value);
      var10003.<init>(var10004, critical1);
      var10001.put(OID, var5);
      var10000.extOrdering.addElement(OID);
   }

   public X509Certificate generateX509Certificate(PrivateKey key) {
      try {
         return this.generateX509Certificate(key, "INFOSEC", (SecureRandom)null);
      } catch (NoSuchProviderException var2) {
         throw new SecurityException("BC provider not installed!");
      }
   }

   public X509Certificate generateX509Certificate(PrivateKey key, SecureRandom random) {
      try {
         return this.generateX509Certificate(key, "INFOSEC", random);
      } catch (NoSuchProviderException var3) {
         throw new SecurityException("BC provider not installed!");
      }
   }

   public X509Certificate generateX509Certificate(PrivateKey key, String provider) {
      return this.generateX509Certificate(key, provider, (SecureRandom)null);
   }

   public X509Certificate generateX509Certificate(PrivateKey key, String provider, SecureRandom random) {
      DERObjectIdentifier var4;
      if ((var4 = this.sigOID) != null) {
         Signature var10000;
         try {
            var10000 = Signature.getInstance(var4.getId(), provider);
         } catch (NoSuchAlgorithmException var6) {
            try {
               var10000 = Signature.getInstance(this.signatureAlgorithm, provider);
            } catch (NoSuchAlgorithmException var5) {
               throw new SecurityException("exception creating signature: " + var5.toString());
            }
         }

         Signature provider1 = var10000;
         if (random != null) {
            provider1.initSign(key, random);
         } else {
            provider1.initSign(key);
         }

         if (this.extensions != null) {
            Vector key1 = this.extOrdering;
            this.tbsGen.setExtensions(new X509Extensions(key1, this.extensions));
         }

         var10000 = provider1;
         TBSCertificateStructure key2 = this.tbsGen.generateTBSCertificate();

         Exception var18;
         label65: {
            ByteArrayOutputStream var17;
            boolean var10001;
            try {
               var17 = new ByteArrayOutputStream;
            } catch (Exception var10) {
               var18 = var10;
               var10001 = false;
               break label65;
            }

            ByteArrayOutputStream random1;
            ByteArrayOutputStream var10002 = random1 = var17;

            DEROutputStream var19;
            try {
               var10002.<init>();
               var19 = new DEROutputStream;
            } catch (Exception var9) {
               var18 = var9;
               var10001 = false;
               break label65;
            }

            DEROutputStream var10003 = var19;

            ASN1EncodableVector var20;
            try {
               var10003.<init>(random1);
               var19.writeObject(key2);
               var10000.update(var17.toByteArray());
               var20 = new ASN1EncodableVector;
            } catch (Exception var8) {
               var18 = var8;
               var10001 = false;
               break label65;
            }

            ASN1EncodableVector random2;
            ASN1EncodableVector var21 = random2 = var20;

            try {
               random2.<init>();
               random2.add(key2);
               var21.add(this.sigAlgId);
               var20.add(new DERBitString(provider1.sign()));
               return new X509CertificateObject(new X509CertificateStructure(new DERSequence(random2)));
            } catch (Exception var7) {
               var18 = var7;
               var10001 = false;
            }
         }

         Exception var11 = var18;
         throw new SecurityException("exception encoding TBS cert - " + var11);
      } else {
         throw new IllegalStateException("no signature algorithm specified");
      }
   }
}
